@@ -22,7 +22,7 @@
  */
 PROCTAB* openproc(int flags, ...) {
     va_list ap;
-    PROCTAB* PT = malloc(sizeof(PROCTAB));
+    PROCTAB* PT = xmalloc(sizeof(PROCTAB));
 
     if (!Do(PID) && !(PT->procfs = opendir("/proc")))
     	return NULL;
@@ -76,8 +76,8 @@ void stat2proc(char* S, proc_t* P) {
     memset(P->cmd, 0, sizeof P->cmd);	/* clear even though *P xcalloc'd ?! */
     sscanf(S, "%d (%39c", &P->pid, P->cmd);
     sscanf(tmp + 2,			/* skip space after ')' too */
-	   "%c %d %d %d %d %d %u %u %u %u %u %d %d %d %d %d "
-	   "%d %u %u %d %u %u %u %u %u %u %u %u %d %d %d %d %u",
+	   "%c %d %d %d %d %d %lu %lu %lu %lu %lu %ld %ld %ld %ld %d "
+	   "%d %lu %lu %ld %lu %lu %lu %lu %lu %lu %lu %lu %d %d %d %d %lu",
 	   &P->state, &P->ppid, &P->pgrp, &P->session, &P->tty, &P->tpgid,
 	   &P->flags, &P->min_flt, &P->cmin_flt, &P->maj_flt, &P->cmaj_flt,
 	   &P->utime, &P->stime, &P->cutime, &P->cstime, &P->priority, &P->nice,
@@ -96,7 +96,7 @@ void stat2proc(char* S, proc_t* P) {
 }
 
 void statm2proc(char* s, proc_t* P) {
-    sscanf(s, "%d %d %d %d %d %d %d",
+    sscanf(s, "%ld %ld %ld %ld %ld %ld %ld",
 	   &P->size, &P->resident, &P->share,
 	   &P->trs, &P->lrs, &P->drs, &P->dt);
 }
@@ -142,7 +142,7 @@ char** file2strvec(char* directory, char* what) {
 	}
 	if (end_of_file && buf[n-1])		/* last read char not null */
 	    buf[n++] = '\0';			/* so append null-terminator */
-	rbuf = realloc(rbuf, tot + n);		/* allocate more memory */
+	rbuf = xrealloc(rbuf, tot + n);		/* allocate more memory */
 	memcpy(rbuf + tot, buf, n);		/* copy buffer into it */
 	tot += n;				/* increment total byte ctr */
 	if (end_of_file)
@@ -160,7 +160,7 @@ char** file2strvec(char* directory, char* what) {
 	    c += sizeof(char*);
     c += sizeof(char*);				/* one extra for NULL term */
 
-    rbuf = realloc(rbuf, tot + c + align);	/* make room for ptrs AT END */
+    rbuf = xrealloc(rbuf, tot + c + align);	/* make room for ptrs AT END */
     endbuf = rbuf + tot;			/* addr just past data buf */
     q = ret = (char**) (endbuf+align);		/* ==> free(*ret) to dealloc */
     *q++ = p = rbuf;				/* point ptrs to the strings */
@@ -359,7 +359,7 @@ proc_t** readproctab(int flags, ...) {
 	PT = openproc(flags);
     va_end(ap);
     do {					/* read table: */
-	tab = realloc(tab, (n+1)*sizeof(proc_t*));/* realloc as we go, using */
+	tab = xrealloc(tab, (n+1)*sizeof(proc_t*));/* realloc as we go, using */
 	tab[n] = readproc(PT, NULL);		  /* final null to terminate */
     } while (tab[n++]);				  /* stop when NULL reached */
     return tab;
