@@ -12,7 +12,10 @@
  * database, forest feature (contributed by ...), environment variables, GNU
  * style long options, pid list filtering (contributed by Michael Shields).
  *
- * Changes Copyright (C) 1993, 1994 Michael K. Johnson,
+ * Michael K. Johnson <johnsonm@redhat.com> again in charge, merging
+ * patches that have accumulated over a long time.
+ *
+ * Changes Copyright (C) 1993, 1994, 1997 Michael K. Johnson,
  *   and   Copyright (C) 1995, 1996 Charles Blake
  * See file COPYING for copyright details.
  */
@@ -35,8 +38,7 @@
 #include <limits.h>
 #include <sys/types.h>
 #include <sys/ioctl.h>
-#include <linux/sched.h>
-#include <linux/tty.h>
+#include <sys/resource.h>
 
 void show_short(char*, proc_t*);
 void show_long (char*, proc_t*);
@@ -105,7 +107,7 @@ int CL_show_env,
     CL_sort     = 1,
     CL_forest,
     CL_Sum,
-    CL_pg_shift = 2;      /* default: show k instead of pages */
+    CL_pg_shift = (PAGE_SHIFT - 10);	/* default: show k instead of pages */
 
 /* Globals */
 
@@ -152,6 +154,9 @@ int main(int argc, char **argv) {
                     } else if (*(p+2) != '\0')	/* just '-- '; not an error */
 			usage("ps: unknown long option\n");
 		}
+		fprintf(stderr,
+			"warning: `-' deprecated; use `ps %s', not `ps %s'\n",
+			(p+1), p);
 		break;
 	      case 'l': CL_fmt = PS_L;   /* replaceable by a */	break;
 	      case 'u': CL_fmt = PS_U;   /* loop over mode[] */	break;
@@ -314,7 +319,7 @@ void show_procs(unsigned maxcmd, int do_header, int pflags, void* args, int N) {
 		show_time(s+strlen(s), next);
 	    add_node(s, next);
 	} else if (CL_sort) {			/*    add process to table */
-	    ptable = realloc(ptable, n*sizeof(proc_t*));
+	    ptable = xrealloc(ptable, n*sizeof(proc_t*));
 	    ptable[n-1] = next;
 	} else {				/*    or show it right away */
 	    show_a_proc(&buf, maxcmd);
@@ -383,15 +388,16 @@ void show_short(char *s, proc_t *p) {
 }
 
 void show_long(char *s, proc_t *p) {
-    char wchanb[10];
+    char wchanb[32];
     
     if (GL_wchan_nout)
-	sprintf(wchanb, " %-9x ", p->wchan);
+	sprintf(wchanb, " %-9lx ", p->wchan & 0xffffffff);
     else
 	sprintf(wchanb, "%-11.11s", wchan(p->wchan));
-    sprintf(s, "%6x %5d %5d %5d %3d %3d %6d %5d %-11.11s %s%3s",
+    sprintf(s, "%6lx %5d %5d %5d %3d %3d %6ld %5ld %-11.11s %s%3s",
 	    p->flags, p->uid, p->pid, p->ppid, p->priority, p->nice,
-	    p->vsize >> 10, p->rss * 4, wchanb, status(p), p->ttyc);
+	    p->vsize >> 10, p->rss << (PAGE_SHIFT - 10), wchanb, status(p),
+	    p->ttyc);
 }
 
 void show_jobs(char *s, proc_t *p) {
@@ -409,18 +415,18 @@ void show_user(char *s, proc_t *p) {
 	s += sprintf(s, "%5d    ", p->uid);
     else
 	s += sprintf(s, "%-8s ", p->user);
-    seconds = (((GL_current_time * 100) - p->start_time) / HZ);
+    seconds = (((GL_current_time * HZ) - p->start_time) / HZ);
     start = GL_time_now - seconds;
     total_time = (p->utime + p->stime +
 		  (CL_Sum ? p->cutime + p->cstime : 0));
     pcpu = seconds ?
-	(total_time * 10) / seconds :
+	(total_time * 10 * 100 / HZ) / seconds :
 	0;
     if (pcpu > 999) pcpu = 999;
-    pmem = p->rss * 1000 / (GL_main_mem >> 12);
-    sprintf(s, "%5d %2u.%u %2d.%d %5d %5d %2s %s%.6s ",
+    pmem = p->rss * 1000 / (GL_main_mem >> PAGE_SHIFT);
+    sprintf(s, "%5d %2u.%u %2d.%d %5ld %5ld %2s %s%.6s ",
 	    p->pid,  pcpu / 10, pcpu % 10,  pmem / 10, pmem % 10,
-	    p->vsize >> 10, p->rss << 2, p->ttyc, status(p),
+	    p->vsize >> 10, p->rss << (PAGE_SHIFT - 10), p->ttyc, status(p),
 	    ctime(&start) + (GL_time_now - start > 3600*24 ? 4 : 10));
 }
 
@@ -436,22 +442,22 @@ void show_vm(char *s, proc_t *p) {
     s += sprintf(s,"%5d %3s %s", p->pid, p->ttyc, status(p));
     show_time(s, p);
     s += strlen(s);
-    s += sprintf(s, " %6d %4d %4d %4d ",
+    s += sprintf(s, " %6ld %4ld %4ld %4ld ",
 		 p->maj_flt + (CL_Sum ? p->cmaj_flt : 0),
 		 p->vsize ? (p->end_code - p->start_code) >> 10 : 0,
 		 p->vsize ? (p->vsize - p->end_code + p->start_code) >> 10 : 0,
-		 p->rss << 2);
+		 p->rss << (PAGE_SHIFT - 10));
     if(p->rss_rlim == RLIM_INFINITY)
 	s += sprintf(s, "   xx ");
     else
-	s += sprintf(s, "%5d ", p->rss_rlim >> 10);
-    pmem = p->rss * 1000 / (GL_main_mem >> 12);
+	s += sprintf(s, "%5ld ", p->rss_rlim >> 10);
+    pmem = p->rss * 1000 / (GL_main_mem >> PAGE_SHIFT);
     sprintf(s, "%2d.%d ", pmem / 10, pmem % 10);
 }
 
 
 void show_m(char *s, proc_t *p) {
-    sprintf(s, "%5d %3s %6d %6d %5d %5d %5d %5d %5d %5d %5d %3d ", 
+    sprintf(s, "%5d %3s %6ld %6ld %5ld %5ld %5ld %5ld %5ld %5ld %5ld %3ld ", 
 	    p->pid, p->ttyc,
 	    p->maj_flt + (CL_Sum ? p->cmaj_flt : 0),
 	    p->min_flt + (CL_Sum ? p->cmin_flt : 0),
@@ -468,7 +474,7 @@ void show_m(char *s, proc_t *p) {
 void show_regs(char *s, proc_t *p) {
     char time1[16], time2[16];
 
-    sprintf(s, "%2d %5d %8x %8x %8x %s %s %s %3s ",
+    sprintf(s, "%2ld %5d %8lx %8lx %8lx %s %s %s %3s ",
 	    p->start_code >> 26, p->pid, p->start_stack,
 	    p->kstk_esp, p->kstk_eip,
 	    prtime(time1, p->timeout, GL_current_time*HZ),
@@ -513,12 +519,12 @@ void add_node(char *s, proc_t *task) {
     if (maxnodes == 0) {
 	maxnodes = 64;
         node = (struct tree_node *)
-            malloc(sizeof(struct tree_node) * maxnodes);
+            xmalloc(sizeof(struct tree_node) * maxnodes);
     }
-    if (nodes > maxnodes) {
+    if (nodes >= maxnodes) {
 	maxnodes *= 2;
         node = (struct tree_node *)
-            realloc(node, sizeof(struct tree_node) * maxnodes);
+            xrealloc(node, sizeof(struct tree_node) * maxnodes);
     }
     node[nodes].proc        = task;
     node[nodes].pid         = task->pid;
@@ -579,14 +585,14 @@ void show_forest() {
         if (parent >= 0) {
             node[i].have_parent++;
             if (node[parent].children == 0) {
-                node[parent].child = (int*)malloc(16 * sizeof(int*));
+                node[parent].child = (int*)xmalloc(16 * sizeof(int*));
                 node[parent].maxchildren = 16;
             }
             else if (node[parent].children == node[parent].maxchildren) {
                 node[parent].maxchildren *= 2;
-                node[parent].child = (int*)realloc(node[parent].child,
-						   node[parent].maxchildren
-						   * sizeof(int*));
+                node[parent].child = (int*)xrealloc(node[parent].child,
+						    node[parent].maxchildren
+						    * sizeof(int*));
             }
             node[parent].child[node[parent].children++] = i;
         }
