@@ -1,5 +1,5 @@
 #ifndef lint
-static char rcsid[] = "$Header: main.c,v 1.12 1994/07/13 20:31:16 forys Exp $";
+static char rcsid[] = "$Header: /usr/rhs/CVS/procps/skill/main.c,v 1.1 1997/09/02 16:02:53 johnsonm Exp $";
 /*
  * SCCS version release number is manually updated (for what(1), etc).
  * If you use SCCS, please use last extension for version (e.g. "3.6.1.1").
@@ -271,7 +271,8 @@ char *
 SysErr()
 {
 	extern int errno;
-#if !defined(_FSTDIO) || defined(_ANSI_SOURCE) || defined(__STRICT_ANSI__)
+#if (!defined(_FSTDIO) || defined(_ANSI_SOURCE) || defined(__STRICT_ANSI__)) \
+	&& __GNU_LIBRARY__ - 0 < 6
 	extern char *sys_errlist[];
 	extern int sys_nerr;
 #endif
